==> letsnet-normapi-1.2.1.tgz: package/index.js <==
var mongoose = require('mongoose')
const fs = require('fs')

var API = function(defaults) {
  mongodb = null
  mongooseCredentials = null

  this.openSchema = null
}

API.prototype.mongoConnect = function() {
  if(this.mongooseCredentials == null) throw 'Please set mongooseCredentials with setMongooseCredentials(object) function ...'
  else this.mongodb = mongoose.createConnection('mongodb://' + this.mongooseCredentials.user + ':' + this.mongooseCredentials.passwd + this.mongooseCredentials.url)
}

API.prototype.mongoClose = function() {
  mongoose.disconnect()
  this.mongodb = null
}

API.prototype.setMongooseCredentials = function(object) {
  if(object.user === 'undefined' || object.user == null) throw 'You must define the \'USER\' of the connection!'
  else if(object.url === 'undefined' || object.url == null) throw 'You must define the \'URL\' of the connection!'
  else if(object.passwd === 'undefined' || object.passwd == null) throw 'You must define the \'PASSWORD\' of the connection!'
  else { this.mongooseCredentials = object }
}

API.prototype.closeMongooseCredentials = function(object) {
  this.mongooseCredentials = null
}

API.prototype.createSchema = function(database, object) {
  if(this.mongodb == null) throw 'Please set a connection with mongoConnect function!'
  else this.openSchema = this.mongodb.model(database, new mongoose.Schema(object))
}

API.prototype.closeSchema = function() {
  this.schema = null
}

API.prototype.addFunction = function(defs, rFunction) {
  this[defs.name] = function (defaults, callback) {
    rFunction(defaults)
    .then(function (defaults) {
        callback(false, {lCode: defaults.lCode || '.API-OBJECT-E1', func: defaults.func || '@rFunction', msg: defaults.msg || 'Sikeres lefutás!', type: defaults.type || 'success', document: defaults.document})
    })
    .catch((defaults) => {
      console.log(defaults)
        callback(true, {lCode: defaults.lCode || '.API-OBJECT-E2', func: defaults.func || '@rFunction', msg: defaults.msg || 'Valami hiba a funkcióban!', type: defaults.type || 'error'})
    })
  }
}

module.exports = API

==> letsnet-normapi-1.2.2.tgz: package/index.js <==
var mongoose = require('mongoose')
const fs = require('fs')

var API = function(defaults) {
  mongodb = null
  mongooseCredentials = null

  this.openSchema = null
}

API.prototype.mongoConnect = function() {
  if(this.mongooseCredentials == null) throw 'Please set mongooseCredentials with setMongooseCredentials(object) function ...'
  else this.mongodb = mongoose.createConnection('mongodb://' + this.mongooseCredentials.user + ':' + this.mongooseCredentials.passwd + this.mongooseCredentials.url)
}

API.prototype.mongoClose = function() {
  mongoose.disconnect()
  this.mongodb = null
}

API.prototype.setMongooseCredentials = function(object) {
  if(object.user === 'undefined' || object.user == null) throw 'You must define the \'USER\' of the connection!'
  else if(object.url === 'undefined' || object.url == null) throw 'You must define the \'URL\' of the connection!'
  else if(object.passwd === 'undefined' || object.passwd == null) throw 'You must define the \'PASSWORD\' of the connection!'
  else { this.mongooseCredentials = object }
}

API.prototype.closeMongooseCredentials = function(object) {
  this.mongooseCredentials = null
}

API.prototype.createSchema = function(database, object) {
  if(this.mongodb == null) throw 'Please set a connection with mongoConnect function!'
  else this.openSchema = this.mongodb.model(database, new mongoose.Schema(object))
}

API.prototype.closeSchema = function() {
  this.schema = null
}

API.prototype.addFunction = function(defs, rFunction) {
  this[defs.name] = function (defaults, callback) {
    rFunction(defaults)
    .then(function (defaults) {

        defaults.func = defaults.func || `@${defs.name}`
        callback(false, {lCode: defaults.lCode || '-D0', func: defaults.func, msg: defaults.msg || 'Sikeres lefutás!', type: defaults.type || 'success', document: defaults.document || null})
    })
    .catch((defaults) => {
        defaults.func = defaults.func || `@${defs.name}`
        callback(true, {lCode: defaults.lCode || '-D0', func: defaults.func, msg: defaults.msg || 'Hiba a funkció lefutása közben!', type: defaults.type || 'error'})
    })
  }
}

module.exports = API
